@@ -35,7 +35,7 @@ except ImportError:
     from json.decoder import JSONDecodeError
 
 # Versioning.
-VERSION = '1.1.15'
+VERSION = '1.1.18'
 
 
 class HTTP:
@@ -73,9 +73,12 @@ class HTTP:
     :param force_retry: Whether or not pybit should retry a timed-out request.
     :type force_retry: bool
 
-    :param retry_codes: A list of non-fatal retry codes to retry on.
+    :param retry_codes: A list of non-fatal status codes to retry on.
     :type retry_codes: set
 
+    :param ignore_codes: A list of non-fatal status codes to ignore.
+    :type ignore_codes: set
+
     :param max_retries: The number of times to re-attempt a request.
     :type max_retries: int
 
@@ -94,8 +97,8 @@ class HTTP:
     def __init__(self, endpoint=None, api_key=None, api_secret=None,
                  logging_level=logging.INFO, log_requests=False,
                  request_timeout=10, recv_window=5000, force_retry=False,
-                 retry_codes=None, max_retries=3, retry_delay=3,
-                 referral_id=None):
+                 retry_codes=None, ignore_codes=None, max_retries=3,
+                 retry_delay=3, referral_id=None):
         """Initializes the HTTP class."""
 
         # Set the endpoint.
@@ -105,12 +108,19 @@ class HTTP:
             self.endpoint = endpoint
 
         # Setup logger.
-        logging.basicConfig(
-            level=logging_level,
-            format='%(asctime)s - %(name)s - %(levelname)s - %(message)s',
-            datefmt='%Y-%m-%d %H:%M:%S'
-        )
+
         self.logger = logging.getLogger(__name__)
+
+        if len(logging.root.handlers) == 0:
+            #no handler on root logger set -> we add handler just for this logger to not mess with custom logic from outside
+            handler = logging.StreamHandler()
+            handler.setFormatter(logging.Formatter(fmt='%(asctime)s - %(name)s - %(levelname)s - %(message)s',
+                                                   datefmt='%Y-%m-%d %H:%M:%S'
+                                                   )
+                                 )
+            handler.setLevel(logging_level)
+            self.logger.addHandler(handler)
+
         self.logger.debug('Initializing HTTP session.')
         self.log_requests = log_requests
 
@@ -125,12 +135,18 @@ class HTTP:
         self.max_retries = max_retries
         self.retry_delay = retry_delay
 
-        # Set whitelist of non-fatal Bybit return error codes to retry
+        # Set whitelist of non-fatal Bybit status codes to retry on.
         if retry_codes is None:
             self.retry_codes = {10002, 10006, 30034, 30035, 130035, 130150}
         else:
             self.retry_codes = retry_codes
 
+        # Set whitelist of non-fatal Bybit status codes to ignore.
+        if ignore_codes is None:
+            self.ignore_codes = set()
+        else:
+            self.ignore_codes = ignore_codes
+
         # Initialize requests session.
         self.client = requests.Session()
         self.client.headers.update(
@@ -532,7 +548,7 @@ class HTTP:
         if kwargs.get('symbol', '').endswith('USDT'):
             suffix = '/private/linear/order/search'
         elif kwargs.get('symbol', '')[-2:].isdigit():
-            suffix = '/futures/private/order/replace'
+            suffix = '/futures/private/order'
         else:
             suffix = '/v2/private/order'
 
@@ -560,11 +576,6 @@ class HTTP:
         else:
             suffix = '/v2/private/stop-order/create'
 
-        if kwargs.get('symbol', '').endswith('USDT'):
-            suffix = '/private/linear/stop-order/create'
-        else:
-            suffix = '/v2/private/stop-order/create'
-
         return self._submit_request(
             method='POST',
             path=self.endpoint + suffix,
@@ -745,7 +756,7 @@ class HTTP:
         if kwargs.get('symbol', '').endswith('USDT'):
             suffix = '/private/linear/stop-order/search'
         elif kwargs.get('symbol', '')[-2:].isdigit():
-            suffix = '/futures/private/stop-ordere'
+            suffix = '/futures/private/stop-order'
         else:
             suffix = '/v2/private/stop-order'
 
@@ -1479,6 +1490,9 @@ class HTTP:
                     time.sleep(err_delay)
                     continue
 
+                elif s_json['ret_code'] in self.ignore_codes:
+                    pass
+
                 else:
                     raise InvalidRequestError(
                         request=f'{method} {path}: {req_params}',
@@ -1554,12 +1568,18 @@ class WebSocket:
         self.wsName = 'Authenticated' if api_key else 'Non-Authenticated'
 
         # Setup logger.
-        logging.basicConfig(
-            level=logging_level,
-            format='%(asctime)s - %(name)s - %(levelname)s - %(message)s',
-            datefmt='%Y-%m-%d %H:%M:%S'
-        )
         self.logger = logging.getLogger(__name__)
+
+        if len(logging.root.handlers) == 0:
+            # no handler on root logger set -> we add handler just for this logger to not mess with custom logic from outside
+            handler = logging.StreamHandler()
+            handler.setFormatter(logging.Formatter(fmt='%(asctime)s - %(name)s - %(levelname)s - %(message)s',
+                                                   datefmt='%Y-%m-%d %H:%M:%S'
+                                                   )
+                                 )
+            handler.setLevel(logging_level)
+            self.logger.addHandler(handler)
+
         self.logger.debug(f'Initializing {self.wsName} WebSocket.')
 
         # Ensure authentication for private topics.
@@ -1679,10 +1699,10 @@ class WebSocket:
 
         self.ws = websocket.WebSocketApp(
             url=url,
-            on_message=self._on_message,
-            on_close=self._on_close,
-            on_open=self._on_open,
-            on_error=self._on_error
+            on_message=lambda ws, msg: self._on_message(msg),
+            on_close=self._on_close(),
+            on_open=self._on_open(),
+            on_error=lambda ws, err: self._on_error(err)
         )
 
         # Setup the thread running WebSocketApp.
